// \file SendmailIntegrate.hpp
//
// Copyright (C) 2011 ARM Research Labs, LLC.
// See www.armresearch.com for the copyright terms.
//
// This file defines the SendmailIntegrate interface.
//
// $Id$
//
///////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef SendmailIntegratehpp_included
#define SendmailIntegratehpp_included

#include <vector>

#include "MtaIntegrate.hpp"

/// Class to manage the SNFMilter integration with sendmail.
//
// This class implements the MtaIntegrate interface for sendmail.
//
//////////////////////////////////////////////////////////////////////////////////////////////////////////
class SendmailIntegrate : public MtaIntegrate {

public:

    virtual void SetOperatingSystem(std::string OperatingSystemType);

    virtual void Integrate(FileBackup *SaveFile);

    virtual void Unintegrate(FileBackup *SaveFile);

private:

    virtual bool MtaIsRunningDetected();

    virtual bool ReloadMta();

    virtual bool IsIntegrated();

    /// Sendmail sendmail.mc file path.
    std::string SendmailSendmailMcPath;

    /// Sendmail sendmail.cf file path.
    std::string SendmailSendmailCfPath;

    /// Command to build and install the sendmail.cf file.
    std::string BuildInstallSendmailCfFile;

    /// Command to reload the MTA.
    std::string ReloadMtaCommand;

    /// typedef for container of filenames to backup up before integrating or unintegrating.
    typedef std::vector<std::string> FileToBackupType;

    /// Files to back up before integrating or unintegrating.
    FileToBackupType FileToBackup;

};

#endif
